@@ -3,7 +3,7 @@ knitr::opts_chunk$set(echo = FALSE)
 
 ## ----echo=TRUE-----------------------------------------------------------
 library(miceFast)
-set.seed(1234)
+set.seed(123456)
 
 ## ----eval=FALSE,echo=TRUE------------------------------------------------
 #  system.file("extdata","performance_validity.R",package = "miceFast")
@@ -42,33 +42,66 @@ head(model$get_data())
 
 rm(model)
 
-## ----echo=TRUE-----------------------------------------------------------
-###################################
-###Model with additional parameters
-###################################
+head(mice::nhanes)
 
+## ----echo=TRUE-----------------------------------------------------------
 data = cbind(as.matrix(airquality[,-5]),intercept=1,index=1:nrow(airquality))
-weights = rgamma(nrow(data),3,3) # positive numeric values
-#groups = airquality[,5] # vector of positive integers
-groups = sample(1:4,nrow(data),replace=T) # vector of positive integers
+weights = rgamma(nrow(data),3,3) # a numeric vector - positive values
+groups = as.numeric(airquality[,5]) # a numeric vector not integers - positive values - sorted increasingly
 
 model = new(miceFast)
 model$set_data(data) # providing data by a reference
 model$set_w(weights)
 model$set_g(groups)
-
-#if data is not sorted increasingly by g then it would be automatically done 
-#during a first imputation
-
 #impute adapt to provided parmaters like w or g
+#Warning - if data is not sorted increasingly by the g then it would be done automatically 
+#during a first imputation
 #Simple mean - permanent imputation at the object and data
 model$update_var(1,model$impute("lm_pred",1,c(6))$imputations)
 
 model$update_var(2,rowMeans(sapply(1:10,function(x) 
   model$impute("lm_bayes",2,c(1,3,4,5,6))$imputations))
   )
+#Printing data and retrieving an old order
+head(cbind(model$get_data(),model$get_g(),model$get_w())[order(model$get_index()),],4)
 
-head(cbind(model$get_data(),model$get_g(),model$get_w())[order(model$get_index()),])
+head(airquality,4)
+
+head(cbind(model$get_data(),model$get_g(),model$get_w()),4)
+
+head(cbind(data,groups,weights),4)
 
 rm(model)
 
+
+## ----echo=TRUE-----------------------------------------------------------
+data = cbind(as.matrix(airquality[,-5]),intercept=1,index=1:nrow(airquality))
+weights = rgamma(nrow(data),3,3) # a numeric vector - positive values
+#groups = as.numeric(airquality[,5]) # a numeric vector not integers - positive values
+groups = as.numeric(sample(1:3,nrow(data),replace=T)) # a numeric vector not integers - positive values
+
+model = new(miceFast)
+model$set_data(data) # providing data by a reference
+model$set_w(weights)
+model$set_g(groups)
+#impute adapt to provided parmaters like w or g
+#Warning - if data is not sorted increasingly by the g then it would be done automatically 
+#during a first imputation
+#Simple mean - permanent imputation at the object and data
+model$update_var(1,model$impute("lm_pred",1,c(6))$imputations)
+
+model$update_var(2,rowMeans(sapply(1:10,function(x) 
+  model$impute("lm_bayes",2,c(1,3,4,5,6))$imputations))
+  )
+#Printing data and retrieving an old order
+head(cbind(model$get_data(),model$get_g(),model$get_w())[order(model$get_index()),],4)
+
+head(airquality,4)
+
+head(cbind(model$get_data(),model$get_g(),model$get_w()),4) #is ordered by g
+
+head(cbind(data,groups,weights),4) #is sorted by g cause we provide data by a reference
+
+rm(model)
+
+
